using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ICustomerApi
    {
        /// <summary>
        /// Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request) This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH NO DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -&gt; Notifications -&gt; Email AND SMS Tabs 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="firstname">Customer First Name</param>
        /// <param name="lastname">Customer Last Name</param>
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param>
        /// <param name="email">Customer Email</param>
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param>
        /// <param name="address">Customer Postal Address</param>
        /// <param name="zipcode">Customer Zipcode</param>
        /// <param name="city">Customer City</param>
        /// <param name="state">Customer State / Province / Region</param>
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <param name="notes">Additional Customer Notes</param>
        /// <returns>string</returns>
        string CreateCustomerAutomatic (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes);
        /// <summary>
        /// Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request) This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH A DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -&gt; Notifications -&gt; Email AND SMS Tabs 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="firstname">Customer First Name</param>
        /// <param name="lastname">Customer Last Name</param>
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param>
        /// <param name="delayBeforeFirstReviewRequest">Delay before sending the first Feedback / Review Request (Allowed values: \&quot;immediately\&quot;, \&quot;X minute\&quot;, \&quot;X hour\&quot;, \&quot;X day\&quot;, \&quot;X week\&quot;, \&quot;X month\&quot;, \&quot;X year\&quot;) </param>
        /// <param name="email">Customer Email</param>
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param>
        /// <param name="address">Customer Postal Address</param>
        /// <param name="zipcode">Customer Zipcode</param>
        /// <param name="city">Customer City</param>
        /// <param name="state">Customer State / Province / Region</param>
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <param name="notes">Additional Customer Notes</param>
        /// <returns></returns>
        void CreateCustomerAutomaticWithDelayReviewRequest (string companyid, string firstname, string lastname, string sendtype, string delayBeforeFirstReviewRequest, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes);
        /// <summary>
        /// Create a Customer AND Feedback / Review Requests This API call creates a Customer in Reputation Builder AND Feedback / Review Request #1 (Email #1 AND/OR SMS #1 ONLY). Feedback / Review Request(s) are then sent immediately 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="firstname">Customer First Name</param>
        /// <param name="lastname">Customer Last Name</param>
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param>
        /// <param name="email">Customer Email</param>
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param>
        /// <param name="address">Customer Postal Address</param>
        /// <param name="zipcode">Customer Zipcode</param>
        /// <param name="city">Customer City</param>
        /// <param name="state">Customer State / Province / Region</param>
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <param name="notes">Additional Customer Notes</param>
        /// <returns></returns>
        void CreateCustomerImmediateFirstReviewRequest (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes);
        /// <summary>
        /// Create a Customer AND a one Feedback / Review Request (Manual Scheduling) This API call creates a Customer in Reputation Builder AND one Feedback / Review Request. You decide which Feedback / Review Request # to send, the sending method (Email or SMS) and you have full control of the sending date and time 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="firstname">Customer First Name</param>
        /// <param name="lastname">Customer Last Name</param>
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param>
        /// <param name="emailnumber">Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param>
        /// <param name="smsnumber">Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param>
        /// <param name="scheduledate">Schedule date (yyyy/mm/dd) </param>
        /// <param name="scheduletime">Schedule time (HH:MM 24 hours format) </param>
        /// <param name="email">Customer Email</param>
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param>
        /// <param name="address">Customer Postal Address</param>
        /// <param name="zipcode">Customer Zipcode</param>
        /// <param name="city">Customer City</param>
        /// <param name="state">Customer State / Province / Region</param>
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <param name="notes">Additional Customer Notes</param>
        /// <returns></returns>
        void CreateCustomerManualScheduleOneReviewRequest (string companyid, string firstname, string lastname, string sendtype, string emailnumber, string smsnumber, string scheduledate, string scheduletime, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes);
        /// <summary>
        /// Delete ONE Customer record This API call deletes an existing Customer from Reputation Builder. It will also delete all Email / SMS Requests still in the Queue
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <returns></returns>
        void DeleteCustomer (string customerid);
        /// <summary>
        /// Get Information on ALL Customers of a Company / Location / Feedback Page This API call returns information from Reputation Builder on ALL existing Customers of a Company / Location / Feedback Page
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;Customer&gt;</returns>
        List<Customer> GetAllCustomersBycompanyId (string companyid);
        /// <summary>
        /// Get a list of Customers who have not yet submitted their Review / Feedback This API call returns the list of Customers of a Company / Location / Feedback Page who have not yet responded to Feedback / Review Requests
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;CustomerWhoHaveNotResponded&gt;</returns>
        List<CustomerWhoHaveNotResponded> GetCustomersWhoHaveNotYetSubmittedReview (string companyid);
        /// <summary>
        /// Get Information of ONE Customer This API call returns information from Reputation Builder on ONE existing Customer
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <returns>List&lt;Customer&gt;</returns>
        List<Customer> GetSingleCustomer (string customerid);
        /// <summary>
        /// Update the record of ONE Customer This API call updates information from Reputation Builder on ONE existing Customer
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <param name="firstname">Customer First Name</param>
        /// <param name="lastname">Customer Last Name</param>
        /// <param name="notes">Additional Customer Notes</param>
        /// <param name="email">Customer Email</param>
        /// <param name="mobile">Customer Mobile Phone</param>
        /// <param name="address">Customer Postal Address</param>
        /// <param name="zipcode">Customer Zipcode</param>
        /// <param name="city">Customer City</param>
        /// <param name="state">Customer State / Province / Region</param>
        /// <param name="country">Customer Country</param>
        /// <param name="language">Customer Language</param>
        /// <returns></returns>
        void UpdateCustomer (string customerid, string firstname, string lastname, string notes, string email, string mobile, string address, string zipcode, string city, string state, string country, string language);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class CustomerApi : ICustomerApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="CustomerApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public CustomerApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="CustomerApi"/> class.
        /// </summary>
        /// <returns></returns>
        public CustomerApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request) This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH NO DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -&gt; Notifications -&gt; Email AND SMS Tabs 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="firstname">Customer First Name</param> 
        /// <param name="lastname">Customer Last Name</param> 
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param> 
        /// <param name="email">Customer Email</param> 
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param> 
        /// <param name="address">Customer Postal Address</param> 
        /// <param name="zipcode">Customer Zipcode</param> 
        /// <param name="city">Customer City</param> 
        /// <param name="state">Customer State / Province / Region</param> 
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <param name="notes">Additional Customer Notes</param> 
        /// <returns>string</returns>            
        public string CreateCustomerAutomatic (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling CreateCustomerAutomatic");
            
            // verify the required parameter 'firstname' is set
            if (firstname == null) throw new ApiException(400, "Missing required parameter 'firstname' when calling CreateCustomerAutomatic");
            
            // verify the required parameter 'lastname' is set
            if (lastname == null) throw new ApiException(400, "Missing required parameter 'lastname' when calling CreateCustomerAutomatic");
            
            // verify the required parameter 'sendtype' is set
            if (sendtype == null) throw new ApiException(400, "Missing required parameter 'sendtype' when calling CreateCustomerAutomatic");
            
    
            var path = "/createCustomerAutomatic";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (companyid != null) formParams.Add("companyid", ApiClient.ParameterToString(companyid)); // form parameter
if (firstname != null) formParams.Add("firstname", ApiClient.ParameterToString(firstname)); // form parameter
if (lastname != null) formParams.Add("lastname", ApiClient.ParameterToString(lastname)); // form parameter
if (email != null) formParams.Add("email", ApiClient.ParameterToString(email)); // form parameter
if (mobile != null) formParams.Add("mobile", ApiClient.ParameterToString(mobile)); // form parameter
if (address != null) formParams.Add("address", ApiClient.ParameterToString(address)); // form parameter
if (zipcode != null) formParams.Add("zipcode", ApiClient.ParameterToString(zipcode)); // form parameter
if (city != null) formParams.Add("city", ApiClient.ParameterToString(city)); // form parameter
if (state != null) formParams.Add("state", ApiClient.ParameterToString(state)); // form parameter
if (country != null) formParams.Add("country", ApiClient.ParameterToString(country)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (sendtype != null) formParams.Add("sendtype", ApiClient.ParameterToString(sendtype)); // form parameter
if (notes != null) formParams.Add("notes", ApiClient.ParameterToString(notes)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerAutomatic: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerAutomatic: " + response.ErrorMessage, response.ErrorMessage);
    
            return (string) ApiClient.Deserialize(response.Content, typeof(string), response.Headers);
        }
    
        /// <summary>
        /// Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request) This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH A DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -&gt; Notifications -&gt; Email AND SMS Tabs 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="firstname">Customer First Name</param> 
        /// <param name="lastname">Customer Last Name</param> 
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param> 
        /// <param name="delayBeforeFirstReviewRequest">Delay before sending the first Feedback / Review Request (Allowed values: \&quot;immediately\&quot;, \&quot;X minute\&quot;, \&quot;X hour\&quot;, \&quot;X day\&quot;, \&quot;X week\&quot;, \&quot;X month\&quot;, \&quot;X year\&quot;) </param> 
        /// <param name="email">Customer Email</param> 
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param> 
        /// <param name="address">Customer Postal Address</param> 
        /// <param name="zipcode">Customer Zipcode</param> 
        /// <param name="city">Customer City</param> 
        /// <param name="state">Customer State / Province / Region</param> 
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <param name="notes">Additional Customer Notes</param> 
        /// <returns></returns>            
        public void CreateCustomerAutomaticWithDelayReviewRequest (string companyid, string firstname, string lastname, string sendtype, string delayBeforeFirstReviewRequest, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling CreateCustomerAutomaticWithDelayReviewRequest");
            
            // verify the required parameter 'firstname' is set
            if (firstname == null) throw new ApiException(400, "Missing required parameter 'firstname' when calling CreateCustomerAutomaticWithDelayReviewRequest");
            
            // verify the required parameter 'lastname' is set
            if (lastname == null) throw new ApiException(400, "Missing required parameter 'lastname' when calling CreateCustomerAutomaticWithDelayReviewRequest");
            
            // verify the required parameter 'sendtype' is set
            if (sendtype == null) throw new ApiException(400, "Missing required parameter 'sendtype' when calling CreateCustomerAutomaticWithDelayReviewRequest");
            
            // verify the required parameter 'delayBeforeFirstReviewRequest' is set
            if (delayBeforeFirstReviewRequest == null) throw new ApiException(400, "Missing required parameter 'delayBeforeFirstReviewRequest' when calling CreateCustomerAutomaticWithDelayReviewRequest");
            
    
            var path = "/createCustomerAutomaticWithDelayReviewRequest";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (companyid != null) formParams.Add("companyid", ApiClient.ParameterToString(companyid)); // form parameter
if (firstname != null) formParams.Add("firstname", ApiClient.ParameterToString(firstname)); // form parameter
if (lastname != null) formParams.Add("lastname", ApiClient.ParameterToString(lastname)); // form parameter
if (email != null) formParams.Add("email", ApiClient.ParameterToString(email)); // form parameter
if (mobile != null) formParams.Add("mobile", ApiClient.ParameterToString(mobile)); // form parameter
if (address != null) formParams.Add("address", ApiClient.ParameterToString(address)); // form parameter
if (zipcode != null) formParams.Add("zipcode", ApiClient.ParameterToString(zipcode)); // form parameter
if (city != null) formParams.Add("city", ApiClient.ParameterToString(city)); // form parameter
if (state != null) formParams.Add("state", ApiClient.ParameterToString(state)); // form parameter
if (country != null) formParams.Add("country", ApiClient.ParameterToString(country)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (sendtype != null) formParams.Add("sendtype", ApiClient.ParameterToString(sendtype)); // form parameter
if (notes != null) formParams.Add("notes", ApiClient.ParameterToString(notes)); // form parameter
if (delayBeforeFirstReviewRequest != null) formParams.Add("delayBeforeFirstReviewRequest", ApiClient.ParameterToString(delayBeforeFirstReviewRequest)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerAutomaticWithDelayReviewRequest: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerAutomaticWithDelayReviewRequest: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Create a Customer AND Feedback / Review Requests This API call creates a Customer in Reputation Builder AND Feedback / Review Request #1 (Email #1 AND/OR SMS #1 ONLY). Feedback / Review Request(s) are then sent immediately 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="firstname">Customer First Name</param> 
        /// <param name="lastname">Customer Last Name</param> 
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param> 
        /// <param name="email">Customer Email</param> 
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param> 
        /// <param name="address">Customer Postal Address</param> 
        /// <param name="zipcode">Customer Zipcode</param> 
        /// <param name="city">Customer City</param> 
        /// <param name="state">Customer State / Province / Region</param> 
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <param name="notes">Additional Customer Notes</param> 
        /// <returns></returns>            
        public void CreateCustomerImmediateFirstReviewRequest (string companyid, string firstname, string lastname, string sendtype, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling CreateCustomerImmediateFirstReviewRequest");
            
            // verify the required parameter 'firstname' is set
            if (firstname == null) throw new ApiException(400, "Missing required parameter 'firstname' when calling CreateCustomerImmediateFirstReviewRequest");
            
            // verify the required parameter 'lastname' is set
            if (lastname == null) throw new ApiException(400, "Missing required parameter 'lastname' when calling CreateCustomerImmediateFirstReviewRequest");
            
            // verify the required parameter 'sendtype' is set
            if (sendtype == null) throw new ApiException(400, "Missing required parameter 'sendtype' when calling CreateCustomerImmediateFirstReviewRequest");
            
    
            var path = "/createCustomerImmediateFirstReviewRequest";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (companyid != null) formParams.Add("companyid", ApiClient.ParameterToString(companyid)); // form parameter
if (firstname != null) formParams.Add("firstname", ApiClient.ParameterToString(firstname)); // form parameter
if (lastname != null) formParams.Add("lastname", ApiClient.ParameterToString(lastname)); // form parameter
if (email != null) formParams.Add("email", ApiClient.ParameterToString(email)); // form parameter
if (mobile != null) formParams.Add("mobile", ApiClient.ParameterToString(mobile)); // form parameter
if (address != null) formParams.Add("address", ApiClient.ParameterToString(address)); // form parameter
if (zipcode != null) formParams.Add("zipcode", ApiClient.ParameterToString(zipcode)); // form parameter
if (city != null) formParams.Add("city", ApiClient.ParameterToString(city)); // form parameter
if (state != null) formParams.Add("state", ApiClient.ParameterToString(state)); // form parameter
if (country != null) formParams.Add("country", ApiClient.ParameterToString(country)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (sendtype != null) formParams.Add("sendtype", ApiClient.ParameterToString(sendtype)); // form parameter
if (notes != null) formParams.Add("notes", ApiClient.ParameterToString(notes)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerImmediateFirstReviewRequest: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerImmediateFirstReviewRequest: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Create a Customer AND a one Feedback / Review Request (Manual Scheduling) This API call creates a Customer in Reputation Builder AND one Feedback / Review Request. You decide which Feedback / Review Request # to send, the sending method (Email or SMS) and you have full control of the sending date and time 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="firstname">Customer First Name</param> 
        /// <param name="lastname">Customer Last Name</param> 
        /// <param name="sendtype">Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot; </param> 
        /// <param name="emailnumber">Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param> 
        /// <param name="smsnumber">Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param> 
        /// <param name="scheduledate">Schedule date (yyyy/mm/dd) </param> 
        /// <param name="scheduletime">Schedule time (HH:MM 24 hours format) </param> 
        /// <param name="email">Customer Email</param> 
        /// <param name="mobile">Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input </param> 
        /// <param name="address">Customer Postal Address</param> 
        /// <param name="zipcode">Customer Zipcode</param> 
        /// <param name="city">Customer City</param> 
        /// <param name="state">Customer State / Province / Region</param> 
        /// <param name="country">Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt </param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <param name="notes">Additional Customer Notes</param> 
        /// <returns></returns>            
        public void CreateCustomerManualScheduleOneReviewRequest (string companyid, string firstname, string lastname, string sendtype, string emailnumber, string smsnumber, string scheduledate, string scheduletime, string email, string mobile, string address, string zipcode, string city, string state, string country, string language, string notes)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'firstname' is set
            if (firstname == null) throw new ApiException(400, "Missing required parameter 'firstname' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'lastname' is set
            if (lastname == null) throw new ApiException(400, "Missing required parameter 'lastname' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'sendtype' is set
            if (sendtype == null) throw new ApiException(400, "Missing required parameter 'sendtype' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'emailnumber' is set
            if (emailnumber == null) throw new ApiException(400, "Missing required parameter 'emailnumber' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'smsnumber' is set
            if (smsnumber == null) throw new ApiException(400, "Missing required parameter 'smsnumber' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'scheduledate' is set
            if (scheduledate == null) throw new ApiException(400, "Missing required parameter 'scheduledate' when calling CreateCustomerManualScheduleOneReviewRequest");
            
            // verify the required parameter 'scheduletime' is set
            if (scheduletime == null) throw new ApiException(400, "Missing required parameter 'scheduletime' when calling CreateCustomerManualScheduleOneReviewRequest");
            
    
            var path = "/createCustomerManualScheduleOneReviewRequest";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (companyid != null) formParams.Add("companyid", ApiClient.ParameterToString(companyid)); // form parameter
if (firstname != null) formParams.Add("firstname", ApiClient.ParameterToString(firstname)); // form parameter
if (lastname != null) formParams.Add("lastname", ApiClient.ParameterToString(lastname)); // form parameter
if (email != null) formParams.Add("email", ApiClient.ParameterToString(email)); // form parameter
if (mobile != null) formParams.Add("mobile", ApiClient.ParameterToString(mobile)); // form parameter
if (address != null) formParams.Add("address", ApiClient.ParameterToString(address)); // form parameter
if (zipcode != null) formParams.Add("zipcode", ApiClient.ParameterToString(zipcode)); // form parameter
if (city != null) formParams.Add("city", ApiClient.ParameterToString(city)); // form parameter
if (state != null) formParams.Add("state", ApiClient.ParameterToString(state)); // form parameter
if (country != null) formParams.Add("country", ApiClient.ParameterToString(country)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (sendtype != null) formParams.Add("sendtype", ApiClient.ParameterToString(sendtype)); // form parameter
if (notes != null) formParams.Add("notes", ApiClient.ParameterToString(notes)); // form parameter
if (emailnumber != null) formParams.Add("emailnumber", ApiClient.ParameterToString(emailnumber)); // form parameter
if (smsnumber != null) formParams.Add("smsnumber", ApiClient.ParameterToString(smsnumber)); // form parameter
if (scheduledate != null) formParams.Add("scheduledate", ApiClient.ParameterToString(scheduledate)); // form parameter
if (scheduletime != null) formParams.Add("scheduletime", ApiClient.ParameterToString(scheduletime)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerManualScheduleOneReviewRequest: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CreateCustomerManualScheduleOneReviewRequest: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Delete ONE Customer record This API call deletes an existing Customer from Reputation Builder. It will also delete all Email / SMS Requests still in the Queue
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <returns></returns>            
        public void DeleteCustomer (string customerid)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling DeleteCustomer");
            
    
            var path = "/deleteCustomer";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.DELETE, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteCustomer: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteCustomer: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Get Information on ALL Customers of a Company / Location / Feedback Page This API call returns information from Reputation Builder on ALL existing Customers of a Company / Location / Feedback Page
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;Customer&gt;</returns>            
        public List<Customer> GetAllCustomersBycompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetAllCustomersBycompanyId");
            
    
            var path = "/getAllCustomersBycompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllCustomersBycompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetAllCustomersBycompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Customer>) ApiClient.Deserialize(response.Content, typeof(List<Customer>), response.Headers);
        }
    
        /// <summary>
        /// Get a list of Customers who have not yet submitted their Review / Feedback This API call returns the list of Customers of a Company / Location / Feedback Page who have not yet responded to Feedback / Review Requests
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;CustomerWhoHaveNotResponded&gt;</returns>            
        public List<CustomerWhoHaveNotResponded> GetCustomersWhoHaveNotYetSubmittedReview (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetCustomersWhoHaveNotYetSubmittedReview");
            
    
            var path = "/getCustomersWhoHaveNotYetSubmittedReview";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetCustomersWhoHaveNotYetSubmittedReview: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetCustomersWhoHaveNotYetSubmittedReview: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<CustomerWhoHaveNotResponded>) ApiClient.Deserialize(response.Content, typeof(List<CustomerWhoHaveNotResponded>), response.Headers);
        }
    
        /// <summary>
        /// Get Information of ONE Customer This API call returns information from Reputation Builder on ONE existing Customer
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <returns>List&lt;Customer&gt;</returns>            
        public List<Customer> GetSingleCustomer (string customerid)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling GetSingleCustomer");
            
    
            var path = "/getSingleCustomer";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (customerid != null) queryParams.Add("customerid", ApiClient.ParameterToString(customerid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSingleCustomer: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSingleCustomer: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Customer>) ApiClient.Deserialize(response.Content, typeof(List<Customer>), response.Headers);
        }
    
        /// <summary>
        /// Update the record of ONE Customer This API call updates information from Reputation Builder on ONE existing Customer
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <param name="firstname">Customer First Name</param> 
        /// <param name="lastname">Customer Last Name</param> 
        /// <param name="notes">Additional Customer Notes</param> 
        /// <param name="email">Customer Email</param> 
        /// <param name="mobile">Customer Mobile Phone</param> 
        /// <param name="address">Customer Postal Address</param> 
        /// <param name="zipcode">Customer Zipcode</param> 
        /// <param name="city">Customer City</param> 
        /// <param name="state">Customer State / Province / Region</param> 
        /// <param name="country">Customer Country</param> 
        /// <param name="language">Customer Language</param> 
        /// <returns></returns>            
        public void UpdateCustomer (string customerid, string firstname, string lastname, string notes, string email, string mobile, string address, string zipcode, string city, string state, string country, string language)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling UpdateCustomer");
            
            // verify the required parameter 'firstname' is set
            if (firstname == null) throw new ApiException(400, "Missing required parameter 'firstname' when calling UpdateCustomer");
            
            // verify the required parameter 'lastname' is set
            if (lastname == null) throw new ApiException(400, "Missing required parameter 'lastname' when calling UpdateCustomer");
            
            // verify the required parameter 'notes' is set
            if (notes == null) throw new ApiException(400, "Missing required parameter 'notes' when calling UpdateCustomer");
            
    
            var path = "/updateCustomer";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
if (firstname != null) formParams.Add("firstname", ApiClient.ParameterToString(firstname)); // form parameter
if (lastname != null) formParams.Add("lastname", ApiClient.ParameterToString(lastname)); // form parameter
if (email != null) formParams.Add("email", ApiClient.ParameterToString(email)); // form parameter
if (mobile != null) formParams.Add("mobile", ApiClient.ParameterToString(mobile)); // form parameter
if (address != null) formParams.Add("address", ApiClient.ParameterToString(address)); // form parameter
if (zipcode != null) formParams.Add("zipcode", ApiClient.ParameterToString(zipcode)); // form parameter
if (city != null) formParams.Add("city", ApiClient.ParameterToString(city)); // form parameter
if (state != null) formParams.Add("state", ApiClient.ParameterToString(state)); // form parameter
if (country != null) formParams.Add("country", ApiClient.ParameterToString(country)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (notes != null) formParams.Add("notes", ApiClient.ParameterToString(notes)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.PUT, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateCustomer: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UpdateCustomer: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
    }
}
