using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IEmailSMSStatsApi
    {
        /// <summary>
        /// Email / SMS sent Email / SMS sent
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <returns>List&lt;EmailSmsSentCount&gt;</returns>
        List<EmailSmsSentCount> GetEmailSmsSentCount (string username);
        /// <summary>
        /// Email / SMS Limit Email / SMS Limit
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <returns>List&lt;EmailSmsSentLimit&gt;</returns>
        List<EmailSmsSentLimit> GetEmailSmsSentLimit (string username);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class EmailSMSStatsApi : IEmailSMSStatsApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EmailSMSStatsApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public EmailSMSStatsApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="EmailSMSStatsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public EmailSMSStatsApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Email / SMS sent Email / SMS sent
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <returns>List&lt;EmailSmsSentCount&gt;</returns>            
        public List<EmailSmsSentCount> GetEmailSmsSentCount (string username)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetEmailSmsSentCount");
            
    
            var path = "/getEmailSmsSentCount";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetEmailSmsSentCount: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetEmailSmsSentCount: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<EmailSmsSentCount>) ApiClient.Deserialize(response.Content, typeof(List<EmailSmsSentCount>), response.Headers);
        }
    
        /// <summary>
        /// Email / SMS Limit Email / SMS Limit
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <returns>List&lt;EmailSmsSentLimit&gt;</returns>            
        public List<EmailSmsSentLimit> GetEmailSmsSentLimit (string username)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetEmailSmsSentLimit");
            
    
            var path = "/getEmailSmsSentLimit";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetEmailSmsSentLimit: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetEmailSmsSentLimit: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<EmailSmsSentLimit>) ApiClient.Deserialize(response.Content, typeof(List<EmailSmsSentLimit>), response.Headers);
        }
    
    }
}
