using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IReviewsApi
    {
        /// <summary>
        /// Get X last reviews less than X days old of a company Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByCompanyID (string companyid, string howManyReviews, string lastHowManyDays);
        /// <summary>
        /// Get X last reviews less than X days old of a review site of a company Get X last reviews less than X days old of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <param name="reviewsSite">Review site name</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByCompanyIDAndReviewSite (string companyid, string howManyReviews, string lastHowManyDays, string reviewsSite);
        /// <summary>
        /// Get X last reviews that equal or over X stars of a review site of a company Get X last reviews that equal or over X stars of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param>
        /// <param name="reviewsSite">Review site name</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByCompanyIDRatingAndReviewSite (string companyid, string howManyReviews, string minimumRatings, string reviewsSite);
        /// <summary>
        /// Get X last reviews that equal or over X stars of a company Get X last reviews that between X stars (For example, last 50 reviews between 2 to 5 stars)
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param>
        /// <param name="maximumRatings">Maximum review rating</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByCompanyIdAndRating (string companyid, string howManyReviews, string lastHowManyDays, string minimumRatings, string maximumRatings);
        /// <summary>
        /// Get X last reviews less than X days old of an account Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByUserName (string username, string howManyReviews, string lastHowManyDays);
        /// <summary>
        /// Get X last reviews that equal or over X stars of an account Get X last reviews that equal or over X stars (For example, last 50 reviews that are equal or over 4 stars)
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByUserNameAndRating (string username, string howManyReviews, string lastHowManyDays, string minimumRatings);
        /// <summary>
        /// Get X last reviews less than X days old of a review site of an account Get X last reviews less than X days old of a review site (For Example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="lastHowManyDays">How many days back</param>
        /// <param name="reviewsSite">Review site name</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByUserNameAndReviewSite (string username, string howManyReviews, string lastHowManyDays, string reviewsSite);
        /// <summary>
        /// Get X last reviews that equal or over X stars of a review site of an account Get X last reviews that equal or over X stars of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="username">User Name or Email address</param>
        /// <param name="howManyReviews">How many reviews</param>
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param>
        /// <param name="reviewsSite">Review site name</param>
        /// <returns>List&lt;Review&gt;</returns>
        List<Review> GetReviewsByUserNameRatingAndReviewSite (string username, string howManyReviews, string minimumRatings, string reviewsSite);
        /// <summary>
        /// Comment on a Feedback / Review This API call posts a Comment on a Feedback / Review. When posted, the Platform sends an Email to the Commenter / Reviewer with a copy of the posted Comment. NOTE: The Moderation Team receives a copy of the Email sent to the Commenter / Reviewer  The API call has the same effect as using the Reputation Control Center (URL: https://reputationcrm.com/reputation-control), locating in the datatable the Feedback / Review that will be commented, and clicking on the &#39;Comment on the Platform&#39; button to leave a Comment  Please refer https://reputationcrm.com/api/repcrm-api-img/CommentOnReview.jpg for more information 
        /// </summary>
        /// <param name="reviewid">Review ID</param>
        /// <param name="commenttext">Comment Text </param>
        /// <returns></returns>
        void PostCommentOnReview (string reviewid, string commenttext);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class ReviewsApi : IReviewsApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewsApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public ReviewsApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ReviewsApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get X last reviews less than X days old of a company Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByCompanyID (string companyid, string howManyReviews, string lastHowManyDays)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetReviewsByCompanyID");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByCompanyID");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByCompanyID");
            
    
            var path = "/getReviewsByCompanyID";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyID: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyID: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews less than X days old of a review site of a company Get X last reviews less than X days old of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <param name="reviewsSite">Review site name</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByCompanyIDAndReviewSite (string companyid, string howManyReviews, string lastHowManyDays, string reviewsSite)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetReviewsByCompanyIDAndReviewSite");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByCompanyIDAndReviewSite");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByCompanyIDAndReviewSite");
            
            // verify the required parameter 'reviewsSite' is set
            if (reviewsSite == null) throw new ApiException(400, "Missing required parameter 'reviewsSite' when calling GetReviewsByCompanyIDAndReviewSite");
            
    
            var path = "/getReviewsByCompanyIDAndReviewSite";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
 if (reviewsSite != null) queryParams.Add("reviewsSite", ApiClient.ParameterToString(reviewsSite)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIDAndReviewSite: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIDAndReviewSite: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews that equal or over X stars of a review site of a company Get X last reviews that equal or over X stars of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param> 
        /// <param name="reviewsSite">Review site name</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByCompanyIDRatingAndReviewSite (string companyid, string howManyReviews, string minimumRatings, string reviewsSite)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetReviewsByCompanyIDRatingAndReviewSite");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByCompanyIDRatingAndReviewSite");
            
            // verify the required parameter 'minimumRatings' is set
            if (minimumRatings == null) throw new ApiException(400, "Missing required parameter 'minimumRatings' when calling GetReviewsByCompanyIDRatingAndReviewSite");
            
            // verify the required parameter 'reviewsSite' is set
            if (reviewsSite == null) throw new ApiException(400, "Missing required parameter 'reviewsSite' when calling GetReviewsByCompanyIDRatingAndReviewSite");
            
    
            var path = "/getReviewsByCompanyIDRatingAndReviewSite";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (minimumRatings != null) queryParams.Add("minimumRatings", ApiClient.ParameterToString(minimumRatings)); // query parameter
 if (reviewsSite != null) queryParams.Add("reviewsSite", ApiClient.ParameterToString(reviewsSite)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIDRatingAndReviewSite: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIDRatingAndReviewSite: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews that equal or over X stars of a company Get X last reviews that between X stars (For example, last 50 reviews between 2 to 5 stars)
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param> 
        /// <param name="maximumRatings">Maximum review rating</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByCompanyIdAndRating (string companyid, string howManyReviews, string lastHowManyDays, string minimumRatings, string maximumRatings)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetReviewsByCompanyIdAndRating");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByCompanyIdAndRating");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByCompanyIdAndRating");
            
            // verify the required parameter 'minimumRatings' is set
            if (minimumRatings == null) throw new ApiException(400, "Missing required parameter 'minimumRatings' when calling GetReviewsByCompanyIdAndRating");
            
            // verify the required parameter 'maximumRatings' is set
            if (maximumRatings == null) throw new ApiException(400, "Missing required parameter 'maximumRatings' when calling GetReviewsByCompanyIdAndRating");
            
    
            var path = "/getReviewsByCompanyIdAndRating";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
 if (minimumRatings != null) queryParams.Add("minimumRatings", ApiClient.ParameterToString(minimumRatings)); // query parameter
 if (maximumRatings != null) queryParams.Add("maximumRatings", ApiClient.ParameterToString(maximumRatings)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIdAndRating: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByCompanyIdAndRating: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews less than X days old of an account Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByUserName (string username, string howManyReviews, string lastHowManyDays)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetReviewsByUserName");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByUserName");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByUserName");
            
    
            var path = "/getReviewsByUserName";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserName: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserName: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews that equal or over X stars of an account Get X last reviews that equal or over X stars (For example, last 50 reviews that are equal or over 4 stars)
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByUserNameAndRating (string username, string howManyReviews, string lastHowManyDays, string minimumRatings)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetReviewsByUserNameAndRating");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByUserNameAndRating");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByUserNameAndRating");
            
            // verify the required parameter 'minimumRatings' is set
            if (minimumRatings == null) throw new ApiException(400, "Missing required parameter 'minimumRatings' when calling GetReviewsByUserNameAndRating");
            
    
            var path = "/getReviewsByUserNameAndRating";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
 if (minimumRatings != null) queryParams.Add("minimumRatings", ApiClient.ParameterToString(minimumRatings)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameAndRating: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameAndRating: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews less than X days old of a review site of an account Get X last reviews less than X days old of a review site (For Example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="lastHowManyDays">How many days back</param> 
        /// <param name="reviewsSite">Review site name</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByUserNameAndReviewSite (string username, string howManyReviews, string lastHowManyDays, string reviewsSite)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetReviewsByUserNameAndReviewSite");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByUserNameAndReviewSite");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetReviewsByUserNameAndReviewSite");
            
            // verify the required parameter 'reviewsSite' is set
            if (reviewsSite == null) throw new ApiException(400, "Missing required parameter 'reviewsSite' when calling GetReviewsByUserNameAndReviewSite");
            
    
            var path = "/getReviewsByUserNameAndReviewSite";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
 if (reviewsSite != null) queryParams.Add("reviewsSite", ApiClient.ParameterToString(reviewsSite)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameAndReviewSite: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameAndReviewSite: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Get X last reviews that equal or over X stars of a review site of an account Get X last reviews that equal or over X stars of a review site (For example, Google reviewsâ€¦)
        /// </summary>
        /// <param name="username">User Name or Email address</param> 
        /// <param name="howManyReviews">How many reviews</param> 
        /// <param name="minimumRatings">Minimum review rating (reviews that are equal or over minimumRatings stars)</param> 
        /// <param name="reviewsSite">Review site name</param> 
        /// <returns>List&lt;Review&gt;</returns>            
        public List<Review> GetReviewsByUserNameRatingAndReviewSite (string username, string howManyReviews, string minimumRatings, string reviewsSite)
        {
            
            // verify the required parameter 'username' is set
            if (username == null) throw new ApiException(400, "Missing required parameter 'username' when calling GetReviewsByUserNameRatingAndReviewSite");
            
            // verify the required parameter 'howManyReviews' is set
            if (howManyReviews == null) throw new ApiException(400, "Missing required parameter 'howManyReviews' when calling GetReviewsByUserNameRatingAndReviewSite");
            
            // verify the required parameter 'minimumRatings' is set
            if (minimumRatings == null) throw new ApiException(400, "Missing required parameter 'minimumRatings' when calling GetReviewsByUserNameRatingAndReviewSite");
            
            // verify the required parameter 'reviewsSite' is set
            if (reviewsSite == null) throw new ApiException(400, "Missing required parameter 'reviewsSite' when calling GetReviewsByUserNameRatingAndReviewSite");
            
    
            var path = "/getReviewsByUserNameRatingAndReviewSite";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (username != null) queryParams.Add("username", ApiClient.ParameterToString(username)); // query parameter
 if (howManyReviews != null) queryParams.Add("howManyReviews", ApiClient.ParameterToString(howManyReviews)); // query parameter
 if (minimumRatings != null) queryParams.Add("minimumRatings", ApiClient.ParameterToString(minimumRatings)); // query parameter
 if (reviewsSite != null) queryParams.Add("reviewsSite", ApiClient.ParameterToString(reviewsSite)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameRatingAndReviewSite: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetReviewsByUserNameRatingAndReviewSite: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Review>) ApiClient.Deserialize(response.Content, typeof(List<Review>), response.Headers);
        }
    
        /// <summary>
        /// Comment on a Feedback / Review This API call posts a Comment on a Feedback / Review. When posted, the Platform sends an Email to the Commenter / Reviewer with a copy of the posted Comment. NOTE: The Moderation Team receives a copy of the Email sent to the Commenter / Reviewer  The API call has the same effect as using the Reputation Control Center (URL: https://reputationcrm.com/reputation-control), locating in the datatable the Feedback / Review that will be commented, and clicking on the &#39;Comment on the Platform&#39; button to leave a Comment  Please refer https://reputationcrm.com/api/repcrm-api-img/CommentOnReview.jpg for more information 
        /// </summary>
        /// <param name="reviewid">Review ID</param> 
        /// <param name="commenttext">Comment Text </param> 
        /// <returns></returns>            
        public void PostCommentOnReview (string reviewid, string commenttext)
        {
            
            // verify the required parameter 'reviewid' is set
            if (reviewid == null) throw new ApiException(400, "Missing required parameter 'reviewid' when calling PostCommentOnReview");
            
            // verify the required parameter 'commenttext' is set
            if (commenttext == null) throw new ApiException(400, "Missing required parameter 'commenttext' when calling PostCommentOnReview");
            
    
            var path = "/postCommentOnReview";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (reviewid != null) formParams.Add("reviewid", ApiClient.ParameterToString(reviewid)); // form parameter
if (commenttext != null) formParams.Add("commenttext", ApiClient.ParameterToString(commenttext)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling PostCommentOnReview: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling PostCommentOnReview: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
    }
}
